==> haskell-http-streams-0.8.7.2-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-streams
version:              0.8.7.2
visibility:           public
id:                   http-streams-0.8.7.2-8p9haEwYShZ3mT1Kyxvo64
key:                  http-streams-0.8.7.2-8p9haEwYShZ3mT1Kyxvo64
license:              BSD-3-Clause
copyright:            © 2012-2020 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/afcowie/http-streams/
synopsis:             An HTTP client using io-streams
description:
    /Overview/

    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  0ba3c7de6b860c878da35b93515e1899
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-8.10.2/site-local/http-streams-0.8.7.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/http-streams-0.8.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/http-streams-0.8.7.2
hs-libraries:         HShttp-streams-0.8.7.2-8p9haEwYShZ3mT1Kyxvo64
depends:
    HsOpenSSL-0.11.5.1-uFCj1K0xkGDO4EztiBZVH
    aeson-1.5.4.1-4wEKZPgDVdkFlnmRCF3GfK
    attoparsec-0.13.2.4-BkYo3BeI9ab9OAiwbGneKH base-4.14.1.0
    base64-bytestring-1.2.0.1-8WzgtfqcHsBDmZhiZcc4kf
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-5DMNWHGVnoo4dOW265EsdJ directory-1.3.6.0
    http-common-0.8.2.1-DQgpQGJwsM358VDYduj59
    io-streams-1.5.2.0-Ca9Dp5CKjCs2i9m43nxcYA mtl-2.2.2
    network-3.1.2.1-DR7SoDNxNxPGBCy1viiSIs
    network-uri-2.6.3.0-9Euob0KzSqAJeAtMbRfaKH
    openssl-streams-1.2.3.0-Loy6ISYQwNIBp3axNyHRN9 text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-7jajDWNmlIpBHz95ShzOz6

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.7.2-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-streams
version:              0.8.7.2
visibility:           public
id:                   http-streams-0.8.7.2-6Uo6N6Yx7n0Hj0bm4SAmZh
key:                  http-streams-0.8.7.2-6Uo6N6Yx7n0Hj0bm4SAmZh
license:              BSD-3-Clause
copyright:            © 2012-2020 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/afcowie/http-streams/
synopsis:             An HTTP client using io-streams
description:
    /Overview/

    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  9306542a8fb81631492d1cf81a70cf63
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-8.10.2/site-local/http-streams-0.8.7.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/http-streams-0.8.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/http-streams-0.8.7.2
hs-libraries:         HShttp-streams-0.8.7.2-6Uo6N6Yx7n0Hj0bm4SAmZh
depends:
    HsOpenSSL-0.11.5.1-38iKyzrAW134lw4Qwm8yme
    aeson-1.5.4.1-7Fmt2H1B65wDOTuTXG6T4t
    attoparsec-0.13.2.4-A3iUKuJR7UBHxmP0AEJfvQ base-4.14.1.0
    base64-bytestring-1.2.0.1-AWZILofJAf294n139sG5uA
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-7Aj4g2iZgZR4Q8sB4UJ8do directory-1.3.6.0
    http-common-0.8.2.1-4o5ZbsFo7q42aq1PYa5lPo
    io-streams-1.5.2.0-KKNkclAsjR74Ybgohd77wJ mtl-2.2.2
    network-3.1.2.1-5n59R95rYCJBWJCbaUzri2
    network-uri-2.6.3.0-FlqrnWVT6WpD3H028R3hh1
    openssl-streams-1.2.3.0-JTm008sObedpUeWnlmAH7 text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-2nDlvtn1IciJcNnZKP7xpJ

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
